pub fn move_executor_forward_and_get<T>(
executor: &mut TestExecutor,
future: impl Future<Output = T>,
panic_msg: &str,
) -> TExpand description
Run the provided future via the executor and return the result of the future.
pub fn move_executor_forward_and_get<T>(
executor: &mut TestExecutor,
future: impl Future<Output = T>,
panic_msg: &str,
) -> TRun the provided future via the executor and return the result of the future.