pub struct InMemoryFidlStorageFactory { /* private fields */ }Expand description
Storage that does not write to disk, for testing.
Implementations
Sourceimpl InMemoryFidlStorageFactory
impl InMemoryFidlStorageFactory
Sourcepub fn new() -> Self
pub fn new() -> Self
Constructs a new InMemoryFidlStorageFactory with the ability to create a FidlStorage
that can only read and write to the storage keys passed in.
Sourcepub async fn initialize_storage<T>(&self)where
T: FidlStorageConvertible,
pub async fn initialize_storage<T>(&self)where
T: FidlStorageConvertible,
Helper method to simplify setup for InMemoryFidlStorageFactory in tests.