pub struct InMemoryStorageFactory { /* private fields */ }Expand description
Storage that does not write to disk, for testing.
Implementations
Sourceimpl InMemoryStorageFactory
impl InMemoryStorageFactory
Sourcepub fn new() -> Self
pub fn new() -> Self
Constructs a new InMemoryStorageFactory with the ability to create a DeviceStorage
that can only read and write to the storage keys passed in.
Sourcepub fn with_initial_data<T>(data: &T) -> Selfwhere
T: DeviceStorageCompatible,
pub fn with_initial_data<T>(data: &T) -> Selfwhere
T: DeviceStorageCompatible,
Constructs a new InMemoryStorageFactory with the data written to stash. This simulates
the data existing in storage before the RestoreAgent reads it.
Sourcepub async fn initialize_storage<T>(&self)where
T: DeviceStorageCompatible,
pub async fn initialize_storage<T>(&self)where
T: DeviceStorageCompatible,
Helper method to simplify setup for InMemoryStorageFactory in tests.
Sourcepub async fn get_device_storage(&self) -> Rc<DeviceStorage>
pub async fn get_device_storage(&self) -> Rc<DeviceStorage>
Retrieve the DeviceStorage singleton.